@@ -32,7 +32,6 @@
 
 #include <Lum/OS/Main.h>
 
-#include <Lum/AppInfo.h>
 #include <Lum/Boolean.h>
 #include <Lum/Button.h>
 #include <Lum/Dialog.h>
@@ -61,7 +60,7 @@
 #define POLL_ERROR_TIMEOUT 60
 
 #include <iostream>
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 class MyWindow : public Lum::Dialog
 {
